@@ -5,6 +5,7 @@
 #pragma once
 
 #include <KNotification>
+#include <MprisQt/MprisManager>
 #include <QtFeedback/QFeedbackEffect>
 
 #include "callutilsinterface.h"
@@ -43,8 +44,17 @@ private:
     void accept(const QString &deviceUni, const QString &callUni);
     void hangUp(const QString &deviceUni, const QString &callUni);
 
+    void pauseMedia();
+    void unpauseMedia();
+
+    void handleIncomingCall(const QString &deviceUni, const QString &callUni, const QString communicationWith);
+    void handleRejectedCall();
+
     org::kde::telephony::CallUtils *_callUtils;
     ContactUtils *_contactUtils;
 
     std::unique_ptr<QFeedbackHapticsEffect> _ringEffect;
+
+    MprisManager _mprisManager;
+    QSet<QString> _pausedSources;
 };
